@@ -52,9 +52,10 @@ class StructureReference(Field):
         super().__init__(kwargs)
 
     def __set__(self, instance, value):
-        if not isinstance(value, dict):
-            raise TypeError("{}: Expected a dictionary".format(self._name))
-        newval = self._newclass(**value)
+        if not(isinstance(value, (dict, Structure))):
+            raise TypeError("{}: Expected a dictionary or Structure; got {}".format(self._name, value))
+        extracted_values =  {k:v for (k, v) in value.__dict__.items() if k != '_instantiated'}if isinstance(value, (Structure,)) else value
+        newval = self._newclass(**extracted_values)
         super().__set__(instance, newval)
 
     def __str__(self):
@@ -127,7 +128,8 @@ class Number(Field):
         Number._validate_static(self, value)
 
     def __set__(self, instance, value):
-        self._validate(value)
+        if not getattr(instance, '_skip_validation', False):
+            self._validate(value)
         super().__set__(instance, value)
 
 
@@ -315,6 +317,7 @@ class _ListStruct(list):
         copied = self.copy()
         copied.append(value)
         setattr(self._instance, getattr(self._array, '_name', None), copied)
+        super().append(value)
 
     def extend(self, value):
         copied = self.copy()
@@ -358,6 +361,7 @@ class _DictStruct(dict):
         copied = self.copy()
         copied.__setitem__(key, value)
         setattr(self._instance, getattr(self._map, '_name', None), copied)
+        super().__setitem__(key, value)
 
     def __delitem__(self, key):
         copied = self.copy()
@@ -744,9 +748,11 @@ class Enum(Field, metaclass=_EnumMeta):
         Enum field. value can be one of predefined values
 
         Arguments:
-             values(`list` or `set` or `tuple`):
-                 allowed values. Can be of any type
-
+             values(`list` or `set` or `tuple`, alternatively an enum Type):
+                 allowed values. Can be of any type.
+                 Alternatively, can be an enum.Enum type. See example below.
+                 When defined with an enum.Enum, serialization converts to strings,
+                 while deserialization expects strings.
         Examples:
 
         .. code-block:: python
@@ -760,15 +766,21 @@ class Enum(Field, metaclass=_EnumMeta):
               arr = Array[Enum[Values]]
               e = Enum['abc', 'x', 'def', 3]
 
-           Example(arr=[Values.ABC, 'DEF'],e=3)
+           example = Example(arr=[Values.ABC, 'DEF'],e=3)
+           assert example.arr = [Values.ABC, Values.DEF]
 
+           # deserialization example:
+           deserialized = Deserializer(target_class=Example).deserialize({'arr': ['GHI', 'DEF', 'ABC'], 'e': 3})
+           assert deserialized.arr == [Values.GHI, Values.DEF, Values.ABC]
     """
 
     def __init__(self, *args, values, **kwargs):
         self._is_enum = isinstance(values, (type,)) and issubclass(values, enum.Enum)
         if self._is_enum:
             self._enum_class = values
-        self.values = values
+            self.values = list(values)
+        else:
+            self.values = values
         super().__init__(*args, **kwargs)
 
     def _validate(self, value):
@@ -788,6 +800,7 @@ class Enum(Field, metaclass=_EnumMeta):
         super().__set__(instance, value)
 
 
+
 class EnumString(Enum, String):
     """
     Combination of :class:`Enum` and :class:`String`. This is useful if you want to further
